## Describe your changes

Please detail the changes you have made, include if relevant:

- Context and motivation for this PR ;
- List of the changes made ;
- List of dependency changes ;
- Breaking changes.

Fixes # (issue)


## Checklist:

- [ ] I have read and followed the [contribution guide](https://ecologits.ai/latest/contributing/).
- [ ] I have performed a self-review of my code.
- [ ] I have added tests that prove my fix is effective or that my feature works.
- [ ] I have successfully run all tests with `make test`.
- [ ] I have successfully run pre-commit with `make pre-commit`.
- [ ] I have written documentation for the changes.
- [ ] I have rebased my branch onto the target branch (usually `main`).
